@@ -3,7 +3,7 @@ from sqlalchemy import create_engine
 from sqlalchemy.orm import scoped_session, sessionmaker
 from sqlalchemy.ext.declarative import declarative_base
 
-postgres_db_uri = "postgres+psycopg2://{user}:{password}@{host}:{port}/{db}".format(
+postgres_db_uri = "postgresql+psycopg2://{user}:{password}@{host}:{port}/{db}".format(
     user=os.getenv("AACT_USER", "root"),
     password=os.getenv("AACT_PASSWORD", "testpass"),
     host=os.getenv("AACT_HOST", "127.0.0.1"),
