@@ -1,7 +1,7 @@
 """Models for storing Mindgram assistant sessions."""
 from datetime import datetime
 
-from sqlalchemy import Column, DateTime, Integer, String
+from sqlalchemy import Column, DateTime, Integer, String, Boolean, ForeignKey
 from sqlalchemy.orm import relationship
 
 from ..AssistantUserQuery.models import AssistantUserQueryModel
@@ -15,12 +15,20 @@ class AssistantSessionModel(Base):
 
     id = Column(Integer, primary_key=True)
     user_id = Column(String(128), nullable=False)
+    type = Column(String(50), nullable=False)
     label = Column(String(128), nullable=False)
     created_at = Column(
         DateTime,
         nullable=False,
         default=lambda: datetime.utcnow(),
     )
+    is_deleted = Column(Boolean, nullable=True)
+    internal_doc_only = Column(Boolean, nullable=True)
+    workbook_id = Column(
+        Integer,
+        ForeignKey("workbooks.id"),
+        nullable=True,
+    )
     updated_at = Column(
         DateTime,
         nullable=False,
