@@ -5,6 +5,7 @@ from sqlalchemy import (
     Integer,
     DateTime,
     String,
+    Boolean,
 )
 
 from ...database import Base
@@ -16,6 +17,7 @@ class CollectionModel(Base):
     id = Column(Integer, primary_key=True)
     name = Column(String(128), nullable=False)
     type = Column(String(50), nullable=False)
+    global_access = Column(Boolean, nullable=True)
     updated_at = Column(
         DateTime,
         nullable=False,
