@@ -14,4 +14,7 @@ class CompanyReviewResourceSchema(Schema):
     note_tag = fields.String(allow_none=True)
     news_id = fields.Integer(allow_none=False)
     reviewed = fields.Boolean(allow_none=True)
+    historical = fields.Boolean(allow_none=True)
+    approval = fields.Boolean(allow_none=True)
+    to_qc = fields.Boolean(allow_none=True)
     updated_at = fields.DateTime(dump_only=True)
