@@ -6,6 +6,7 @@ from sqlalchemy import (
     DateTime,
     ForeignKey,
     Boolean,
+    Text,
     String,
 )
 
@@ -22,6 +23,12 @@ class DesignationModel(Base):
         nullable=False,
     )
     designation = Column(String(128), nullable=False, index=True)
+    news_id = Column(
+        Integer,
+        ForeignKey('newswires.id'),
+        nullable=True,
+    )
+    designation_text = Column(Text, nullable=True)
     is_deleted = Column(Boolean, nullable=True)
     updated_at = Column(
         DateTime,
