@@ -17,6 +17,8 @@ class DrugIndicationModel(Base):
 
     id = Column(Integer, primary_key=True)
     set_id = Column(String(128), nullable=False, index=True)
+    doc_id = Column(String(128), nullable=False, index=True)
+    version = Column(String(20), nullable=False)
     lowercase_indication = Column(String(128), nullable=True)
     indication = Column(Text, nullable=True)
     label_file_id = Column(
