@@ -18,4 +18,6 @@ class FDALabelResourceSchema(Schema):
     section_type = fields.String(required=True)
     section_html_file_id = fields.Integer(allow_none=True)
     label_html_file_id = fields.Integer(required=True)
+    is_active = fields.Boolean(allow_none=True)
+    vector_active = fields.Boolean(allow_none=True)
     updated_at = fields.DateTime(dump_only=True)
