@@ -6,7 +6,7 @@ from sqlalchemy import (
     DateTime,
     ForeignKey,
     String,
-    Boolean,
+    Text,
 )
 
 from ...database import Base
@@ -31,14 +31,17 @@ class InterventionDataModel(Base):
         ForeignKey('pubmed.id'),
         nullable=True,
     )
-    file_id = Column(
+    company_filing_id = Column(
         Integer,
-        ForeignKey('files.id'),
+        ForeignKey('company_filings.id'),
         nullable=True,
     )
-    title = Column(String(255), nullable=True)
-    orig_file_url = Column(String(255), nullable=True)
-    is_deleted = Column(Boolean, nullable=True)
+    fda_label_id = Column(
+        Integer,
+        ForeignKey('fda_labels.id'),
+        nullable=True,
+    )
+    info = Column(Text, nullable=True)
     updated_at = Column(
         DateTime,
         nullable=False,
