@@ -11,4 +11,6 @@ class NewswireFinancingOutboxResourceSchema(Schema):
     id = fields.Integer(dump_only=True)
     news_id = fields.Integer(required=True)
     source = fields.String(required=True)
+    submitted = fields.Boolean(allow_none=True)
+    historical = fields.Boolean(allow_none=True)
     updated_at = fields.DateTime()
