@@ -11,4 +11,6 @@ class PubmedPMCResourceSchema(Schema):
     id = fields.Integer(dump_only=True)
     pubmed_id = fields.Integer(required=True)
     pmc_id = fields.String(required=True)
+    processed = fields.Boolean(allow_none=True)
+    found = fields.Boolean(allow_none=True)
     updated_at = fields.DateTime()
