@@ -2,6 +2,7 @@ from sqlalchemy import (
     Column,
     Integer,
     String,
+    Boolean,
     DateTime,
     ForeignKey,
 )
@@ -20,6 +21,9 @@ class TargetSynModel(Base):
         ForeignKey('targets.id'),
         nullable=True,
     )
+    source = Column(String(50), nullable=True)
+    obsolete = Column(Boolean, nullable=True)
+    synonym_type = Column(String(50), nullable=True)
     updated_at = Column(
         DateTime,
         nullable=False,
